@@ -28,6 +28,55 @@ import aws_cdk.aws_elasticloadbalancingv2
 import aws_cdk.aws_lambda
 
 
+@jsii.implements(aws_cdk.aws_elasticloadbalancingv2.INetworkLoadBalancerTarget)
+class AlbArnTarget(
+    metaclass=jsii.JSIIMeta,
+    jsii_type="@aws-cdk/aws-elasticloadbalancingv2-targets.AlbArnTarget",
+):
+    '''A single Application Load Balancer as the target for load balancing.'''
+
+    def __init__(self, alb_arn: builtins.str, port: jsii.Number) -> None:
+        '''Create a new alb target.
+
+        :param alb_arn: The ARN of the application load balancer to load balance to.
+        :param port: The port on which the target is listening.
+        '''
+        jsii.create(self.__class__, self, [alb_arn, port])
+
+    @jsii.member(jsii_name="attachToNetworkTargetGroup")
+    def attach_to_network_target_group(
+        self,
+        target_group: aws_cdk.aws_elasticloadbalancingv2.INetworkTargetGroup,
+    ) -> aws_cdk.aws_elasticloadbalancingv2.LoadBalancerTargetProps:
+        '''Register this alb target with a load balancer.
+
+        Don't call this, it is called automatically when you add the target to a
+        load balancer.
+
+        :param target_group: -
+        '''
+        return typing.cast(aws_cdk.aws_elasticloadbalancingv2.LoadBalancerTargetProps, jsii.invoke(self, "attachToNetworkTargetGroup", [target_group]))
+
+
+class AlbTarget(
+    AlbArnTarget,
+    metaclass=jsii.JSIIMeta,
+    jsii_type="@aws-cdk/aws-elasticloadbalancingv2-targets.AlbTarget",
+):
+    '''A single Application Load Balancer as the target for load balancing.'''
+
+    def __init__(
+        self,
+        alb: aws_cdk.aws_elasticloadbalancingv2.ApplicationLoadBalancer,
+        port: jsii.Number,
+    ) -> None:
+        '''
+        :param alb: The application load balancer to load balance to.
+        :param port: The port on which the target is listening.
+        '''
+        jsii.create(self.__class__, self, [alb, port])
+
+
 @jsii.implements(aws_cdk.aws_elasticloadbalancingv2.IApplicationLoadBalancerTarget, aws_cdk.aws_elasticloadbalancingv2.INetworkLoadBalancerTarget)
 class InstanceIdTarget(
     metaclass=jsii.JSIIMeta,
@@ -214,6 +263,8 @@ class LambdaTarget(
 
 
 __all__ = [
+    "AlbArnTarget",
+    "AlbTarget",
     "InstanceIdTarget",
     "InstanceTarget",
     "IpTarget",
